Installation
============

This package is not yet released on PyPI. You can still install it using ``pip``
by specifying the GitHub repository as the source:

.. code:: shell

   pip install git+https://github.com/dhrosa/bamboo_stash

